==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/LossSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LossSpecFluent<A extends LossSpecFluent<A>> extends BaseFluent<A>{
  public LossSpecFluent() {
  }
  
  public LossSpecFluent(LossSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String loss;
  
  protected void copyInstance(LossSpec instance) {
    instance = (instance != null ? instance : new LossSpec());
  
    if (instance != null) {
        this.withCorrelation(instance.getCorrelation());
        this.withLoss(instance.getLoss());
        this.withCorrelation(instance.getCorrelation());
        this.withLoss(instance.getLoss());
      }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation=correlation; return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getLoss() {
    return this.loss;
  }
  
  public A withLoss(String loss) {
    this.loss=loss; return (A) this;
  }
  
  public boolean hasLoss() {
    return this.loss != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LossSpecFluent that = (LossSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
  
    if (!java.util.Objects.equals(loss, that.loss)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  loss,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (loss != null) { sb.append("loss:"); sb.append(loss); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/LossSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LossSpecFluent<A extends LossSpecFluent<A>> extends BaseFluent<A>{
  public LossSpecFluent() {
  }
  
  public LossSpecFluent(LossSpec instance) {
    this.copyInstance(instance);
  }
  private String correlation;
  private String loss;
  
  protected void copyInstance(LossSpec instance) {
    instance = (instance != null ? instance : new LossSpec());
    if (instance != null) {
          this.withCorrelation(instance.getCorrelation());
          this.withLoss(instance.getLoss());
          this.withCorrelation(instance.getCorrelation());
          this.withLoss(instance.getLoss());
        }
  }
  
  public String getCorrelation() {
    return this.correlation;
  }
  
  public A withCorrelation(String correlation) {
    this.correlation = correlation;
    return (A) this;
  }
  
  public boolean hasCorrelation() {
    return this.correlation != null;
  }
  
  public String getLoss() {
    return this.loss;
  }
  
  public A withLoss(String loss) {
    this.loss = loss;
    return (A) this;
  }
  
  public boolean hasLoss() {
    return this.loss != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LossSpecFluent that = (LossSpecFluent) o;
    if (!java.util.Objects.equals(correlation, that.correlation)) return false;
    if (!java.util.Objects.equals(loss, that.loss)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(correlation,  loss,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (correlation != null) { sb.append("correlation:"); sb.append(correlation + ","); }
    if (loss != null) { sb.append("loss:"); sb.append(loss); }
    sb.append("}");
    return sb.toString();
  }
  

}
